@@ -39,11 +39,13 @@ class DataMediator:
         controlIDs: list,
         experimentalIDs: list,
         randomSeed: int,
+        balancingMethod: str = "downsampling",
         **kwargs,
     ) -> None:
         self.dataframe = dataframe
         self.testProportion = testProportion
         self.randomSeed = randomSeed
+        self.balancingMethod = balancingMethod
 
         # split experimental & control data with given IDs
         self.experimental = self.__splitDataFrame(experimentalIDs)
@@ -62,19 +64,14 @@ class DataMediator:
             del kwargs["holdoutProportion"]
         for flag, value in kwargs.items():
             # TODO: refactor using match case upon python 3.10 release
-            if flag == "balancingMethod":
-                # balance with given sampling method
-                self.balancingMethod = value
-                if "balancingMethodCallback" in kwargs:
-                    self.balancingMethodCallback = kwargs["balancingMethodCallback"]
-                    self.__balance(value, self.balancingMethodCallback)
-                else:
-                    self.balancingMethodCallback = None
-                    self.__balance(value)
+            # balance with given sampling method
+            if flag == "balancingMethodCallback":
+                self.balancingMethodCallback = value
             if flag == "filterMap":
                 self.filter(value)
             if flag == "verbose":
                 self.verbose = value
+            self.__balance(self.balancingMethodCallback)
 
     @staticmethod
     def transposeDataFrame(
@@ -153,7 +150,6 @@ class DataMediator:
 
     def __balance(
         self,
-        balancingMethod: str = "downsampling",
         balancingMethodCallback: Optional[Callable] = None,
     ) -> None:
         """
@@ -162,12 +158,8 @@ class DataMediator:
         are additional options. A custom sampling method callback may also be passed,
         which is called instead on split & holdout dataframes.
         """
-        largeSplit = max(
-            [self.experimental.copy(deep=True), self.control.copy(deep=True)], key=len
-        )
-        smallSplit = min(
-            [self.experimental.copy(deep=True), self.control.copy(deep=True)], key=len
-        )
+        largeSplit = max([self.experimental, self.control], key=len)
+        smallSplit = min([self.experimental, self.control], key=len)
 
         if hasattr(self, "verbose"):
             print(f"Unbalanced classes— {False if largeSplit == smallSplit else True}")
@@ -177,22 +169,19 @@ class DataMediator:
         # Balancing the Data
         # ignore chained assigment warning in Pandas since we are dropping rows in-place
         pd.options.mode.chained_assignment = None
-        if balancingMethodCallback and balancingMethod == "downsampling":
+        if balancingMethodCallback and self.balancingMethod == "downsampling":
             dataToDrop = balancingMethodCallback(largeSplit)
             largeSplit.drop(
                 dataToDrop.index.symmetric_difference(largeSplit.index), inplace=True
             )
-        elif balancingMethodCallback and balancingMethod == "upsampling":
+        elif balancingMethodCallback and self.balancingMethod == "upsampling":
             dataToAdd = balancingMethodCallback(smallSplit)
             smallSplit.merge(dataToAdd)
-        elif balancingMethod == "downsampling":
-            dataToDrop = largeSplit.sample(
+        elif self.balancingMethod == "downsampling":
+            largeSplit = largeSplit.sample(
                 len(smallSplit), random_state=self.randomSeed
             )
-            largeSplit.drop(
-                dataToDrop.index.symmetric_difference(largeSplit.index), inplace=True
-            )
-        elif balancingMethod == "upsampling":
+        elif self.balancingMethod == "upsampling":
             dataToAdd = smallSplit.sample(
                 len(largeSplit), replace=True, random_state=self.randomSeed
             )
